 /* ****************************************************************************
  Projeto: Dado Eletronico com 7 leds

  Autor: Cludio Lrios
  
  Data: 10/04/2021
  
  Hardware: Blue_Pill (STM32F103C8T6)

  Blog: PicSource
  
  Conecte leds ao portA atravs de resistores de 1k, nos pinos A0,A1,A2,A3
  conforme esquema:
  
       a0              a1
       
       a2      a3      a2
  
       a1              a0
  
  Funciona ao apertar o interruptor 'PLAY' (ligado no pino PB0 ao vcc).
  No pino PB0 deve ser colocado um resistor de 10k ao gnd (pulldown externo).
  Ligue um disco piezoeletrico no pino B8 ao gnd (para o 'beep').


  Uso didtico apenas.

  Compilador C:   MikroC PRO for Arm v6.2.0 (free version)
  Programador: ST_Link-v2

*******************************************************************************/
unsigned  char sort;
unsigned  long cnt,a;


void beep(){
  for(a=0;a<1000;a++){  //Gera apito em PA8 (disco piezo ao gnd)
    GPIOA_ODR = GPIOA_ODR | 0B100000000;  //seta pino A8
    delay_us(67);
    GPIOA_ODR = GPIOA_ODR & 0B011111111;  //reseta pino A8
    delay_us(67);
  }
}


//Lao principal de repetio
void main(){
 #define ledsApagados 0
 #define ledsA 1
 #define ledsB 2
 #define ledsC 4
 #define ledsD 8
 #define VDEBOUNCING  20000
 
 
  GPIO_Digital_Output(&GPIOA_BASE, _GPIO_PINMASK_ALL); //configura portA como sadas
  GPIO_Digital_Input(&GPIOB_IDR, _GPIO_PINMASK_LOW);
  
  GPIOA_ODR=15;//testa leds
  beep(); //testa apito
  delay_ms(500);
  GPIOA_ODR=0;
  
          while(1){

                 while (GPIOB_IDR.B0==0){    // Enquanto o boto em PB0 no for apertado
                   sort++;  //incrementa contador de sorteio
                   if(sort>6)sort=0;  //limita a 6
                 }
                 //sorteia o nmero a ser visualizado pelos led de 0 a 6 ( 0 = todos apagados)
                 if(sort==0)GPIOA_ODR=ledsApagados; //0-apaga todos leds
                 if(sort==1)GPIOA_ODR=ledsD;//8-acende 1 led em PA3
                 if(sort==2)GPIOA_ODR=ledsA; //1-acende 2 leds em PA0
                 if(sort==3)GPIOA_ODR=ledsA|ledsD;//9-acende 2 leds em PA0 e 1 led em PA3
                 if(sort==4)GPIOA_ODR=ledsA|ledsB;//3-acende 2 leds em PA0 e 2 leds em PA1
                 if(sort==5)GPIOA_ODR=ledsA|ledsB|ledsD;//11-acende 2 leds em PA0, 2 em PA1 e 1 em PA3
                 if(sort==6)GPIOA_ODR=ledsA|ledsB|ledsC;//7-acende 2 leds em PA1, 2 em PA0 e 2 em PA2

                 beep();//apita
                 
                 //debouncing do boto
                 cnt=VDEBOUNCING;
                 while(cnt>0){
                   if( GPIOB_IDR.B0==0){//enquanto boto  zero
                      cnt--;  //decrementa visando sair do lao while
                      sort++; //incrementa contador de sorteio
                      if(sort>6)sort=0; //limita a 6
                   }
                   else{
                    cnt=VDEBOUNCING;//recarrega na presena de debouncing
                    }
                  }
            }



}
//*********************Fim do Programa******************************************